@@ -30,6 +30,9 @@ class Google(object):
 
         url = self._get_url()
 
+        if self.verbose:
+            print url
+
         try:
             f = urllib.urlopen(url)
             output = f.read()
@@ -74,7 +77,6 @@ class Google(object):
                         result['status'] == "INVALID_REQUEST":
                     print 'Fetch rejected: %s' % result['status']
                     print url
-        #except ValueError as e:
         except Exception as e:
             # can happen if URL is too large or if
             # connection problems with google
@@ -136,7 +138,7 @@ class GooglePremium(Google):
         return '%s&signature=%s' % (originalUrl, encodedSignature)
 
 
-class Location():
+class Location(object):
     """
     Stores location information related to an address
     """
@@ -230,7 +232,7 @@ class Location():
             #print s_addr
             #print g_addr
 
-            # if street returned buy google starts or ends with a single
+            # if street returned by google starts or ends with a single
             # character (e.g N, E, S or W) remove it
             if re.match('\w ', g_addr):
                 g_addr = g_addr[2: len(g_addr)]
